@@ -1,14 +1,15 @@
 package Mojolicious::Plugin::OpenAPI::Security;
 use Mojo::Base -base;
 
-my %DEF_PATH = (2 => '/securityDefinitions', 3 => '/components/securitySchemes');
+my %DEF_PATH
+  = ('openapiv2' => '/securityDefinitions', 'openapiv3' => '/components/securitySchemes');
 
 sub register {
   my ($self, $app, $config) = @_;
   my $openapi  = $config->{openapi};
   my $handlers = $config->{security} or return;
 
-  return unless $openapi->validator->get($DEF_PATH{$openapi->validator->version});
+  return unless $openapi->validator->get($DEF_PATH{$openapi->validator->moniker});
   return $openapi->route(
     $openapi->route->under('/')->to(cb => $self->_build_action($openapi, $handlers)));
 }
@@ -16,7 +17,7 @@ sub register {
 sub _build_action {
   my ($self, $openapi, $handlers) = @_;
   my $global      = $openapi->validator->get('/security') || [];
-  my $definitions = $openapi->validator->get($DEF_PATH{$openapi->validator->version});
+  my $definitions = $openapi->validator->get($DEF_PATH{$openapi->validator->moniker});
 
   return sub {
     my $c = shift;
@@ -55,7 +56,7 @@ sub _build_action {
         push @errors, @e;
         $i++;
       }
-
+      $status = $c->stash('status') || $status if $status < 500;
       $c->render(openapi => {errors => \@errors}, status => $status);
       $n_checks = -1;    # Make sure we don't render twice
     };
@@ -66,6 +67,7 @@ sub _build_action {
 
         if (!$security_cb) {
           $res{$name} = {message => "No security callback for $name."} unless exists $res{$name};
+          $security_completed->(); # missing handler is always an error
         }
         elsif (!exists $res{$name}) {
           $res{$name} = undef;
